TextInkOverflow

Enum TextInkOverflow 

pub enum TextInkOverflow {
    None,
    AutoPad,
}

Variants



None

Do not apply any extra padding; tall glyph ink may be clipped if an ancestor clips.



AutoPad

Adds top/bottom padding to accommodate first/last-line ink extents when available.

Notes:

  • This is best-effort: if ink metrics are unavailable, no padding is applied.
  • If the widget is height-constrained, padding may be partially applied (or ignored).