pub struct CanvasCacheTuning {
pub keep_frames: u64,
pub max_entries: usize,
}Expand description
Cache tuning for a single hosted resource kind (text/path/svg) within a declarative Canvas.
Fields
keep_frames: u64How long an unused entry may remain cached (in UI frames).
max_entries: usizeHard cap on cached entries for this resource kind.
Implementations