pub struct PressableProps {
pub layout: LayoutStyle,
pub enabled: bool,
pub focusable: bool,
pub focus_ring: Option<RingStyle>,
pub focus_ring_always_paint: bool,
pub focus_ring_bounds: Option<Rect>,
pub key_activation: PressableKeyActivation,
pub a11y: PressableA11y,
}Fields
layout: LayoutStyleenabled: boolfocusable: boolWhether this pressable is a focus traversal stop (Tab order).
When false, the node can still be focused programmatically (e.g. roving focus),
but it is skipped by the default focus traversal.
focus_ring: Option<RingStyle>focus_ring_always_paint: boolWhen true, paint the focus ring even when the pressable is not focused.
This is intended for component-layer animation parity with CSS transition outcomes where
focus ring (box-shadow-like) decorations can animate out after focus changes.
When false (default), the focus ring is painted only while focus-visible is active on the
pressable.
focus_ring_bounds: Option<Rect>Optional override for the bounds used when painting the focus ring.
Coordinates are local to the pressable’s origin (i.e. 0,0 is the pressable’s top-left),
and are translated into absolute coordinates at paint time.
This is useful when the pressable is wider than the visual control chrome (e.g. a “row” pressable that should paint focus ring only around an icon-sized control).
key_activation: PressableKeyActivationa11y: PressableA11yTrait Implementations
Sourceimpl Clone for PressableProps
impl Clone for PressableProps
Sourcefn clone(&self) -> PressableProps
fn clone(&self) -> PressableProps
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more