pub struct RenderTransformProps {
pub layout: LayoutStyle,
pub transform: Transform2D,
}Expand description
Render transform wrapper for declarative element subtrees.
This applies Widget::render_transform(...) for the subtree rooted at this element:
- Paint and hit-testing are both transformed.
- Pointer event coordinates are mapped through the inverse transform (when invertible).
- Layout bounds remain authoritative (this is not a layout transform).
This is useful for interactive translations (e.g. drag-to-dismiss surfaces) that must keep input aligned with the rendered output.
Fields
layout: LayoutStyletransform: Transform2DTrait Implementations
Sourceimpl Clone for RenderTransformProps
impl Clone for RenderTransformProps
Sourcefn clone(&self) -> RenderTransformProps
fn clone(&self) -> RenderTransformProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderTransformProps
impl Debug for RenderTransformProps
Sourceimpl Default for RenderTransformProps
impl Default for RenderTransformProps
Sourcefn default() -> RenderTransformProps
fn default() -> RenderTransformProps
Returns the “default value” for a type. Read more
impl Copy for RenderTransformProps