pub struct SvgIconProps {
pub layout: LayoutStyle,
pub svg: SvgSource,
pub fit: SvgFit,
pub color: Color,
pub inherit_color: bool,
pub opacity: f32,
}Fields
layout: LayoutStylesvg: SvgSourcefit: SvgFitcolor: Colorinherit_color: boolWhen true, the icon will use the nearest inherited foreground (if present) during paint.
When no foreground is inherited, color is used as the fallback.
opacity: f32Implementations