pub struct TextAreaProps {Show 13 fields
pub layout: LayoutStyle,
pub enabled: bool,
pub focusable: bool,
pub model: Model<String>,
pub placeholder: Option<Arc<str>>,
pub a11y_required: bool,
pub a11y_invalid: Option<SemanticsInvalid>,
pub a11y_label: Option<Arc<str>>,
pub test_id: Option<Arc<str>>,
pub chrome: TextAreaStyle,
pub focus_ring_always_paint: bool,
pub text_style: TextStyle,
pub min_height: Px,
}Fields
layout: LayoutStyleenabled: boolfocusable: boolmodel: Model<String>placeholder: Option<Arc<str>>a11y_required: boola11y_invalid: Option<SemanticsInvalid>a11y_label: Option<Arc<str>>test_id: Option<Arc<str>>chrome: TextAreaStylefocus_ring_always_paint: boolWhen true, paints the focus ring even if focus-visible is currently false.
This exists to support CSS-like transition-[..., box-shadow] semantics where the ring
animates out after blur. Policy code is expected to drive ring alpha to zero and set this
flag only while the transition is animating.
text_style: TextStylemin_height: PxImplementations