pub struct WheelRegionProps {
pub layout: LayoutStyle,
pub axis: ScrollAxis,
pub scroll_target: Option<GlobalElementId>,
pub scroll_handle: ScrollHandle,
}Expand description
A wheel listener region that mutates a scroll handle without affecting layout.
Fields
layout: LayoutStyleaxis: ScrollAxisscroll_target: Option<GlobalElementId>Declarative element id to invalidate when the scroll offset changes.
scroll_handle: ScrollHandleTrait Implementations
Sourceimpl Clone for WheelRegionProps
impl Clone for WheelRegionProps
Sourcefn clone(&self) -> WheelRegionProps
fn clone(&self) -> WheelRegionProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WheelRegionProps
impl Debug for WheelRegionProps