Module elements

Module elements 

Structs

ContinuousFrames
ElementContext
Per-frame view construction context passed to declarative element constructors.
ElementRuntime
GlobalElementId
WindowElementState

Traits

ElementContextAccess
Explicit access contract for APIs that only need to land UI through an ElementContext.

Functions

bounds_for_element
Returns the most recent committed bounds for a declarative element, if available.
current_bounds_for_element
Returns the most recent recorded bounds for element, including the current frame’s in-progress layout deltas.
current_visual_bounds_for_element
Returns the most recent recorded visual bounds for element, including the current frame’s in-progress layout deltas.
dismissible_has_pointer_move_handler
Returns true if the given element currently has an on_pointer_move hook installed for DismissibleLayer.
element_identity_is_live_in_current_frame
Returns whether element participated in the current frame’s declarative authoring pass.
element_is_live_in_current_frame
Returns whether element is known to be mounted in the current frame.
global_root
live_node_for_element
Returns the current-frame node mapping for element, if available.
node_for_element
Returns the most recent retained NodeId mapping for element.
peek_node_for_element
Returns the most recent NodeId mapping for element without preparing element runtime for the current frame.
root_bounds_for_element
take_element_state
visual_bounds_for_element
Returns the most recent committed visual bounds (post-render_transform AABB) for a declarative element, if available.
with_element_cx
with_element_state