TextAreaStyle

Struct TextAreaStyle 

pub struct TextAreaStyle {
Show 14 fields pub padding_x: Px, pub padding_y: Px, pub background: Color, pub border: Edges, pub border_color: Color, pub border_color_focused: Color, pub focus_ring: Option<RingStyle>, pub corner_radii: Corners, pub text_color: Color, pub placeholder_color: Color, pub selection_color: Color, pub caret_color: Color, pub preedit_bg_color: Color, pub preedit_underline_color: Color,
}

Fields

padding_x: Pxpadding_y: Pxbackground: Colorborder: Edgesborder_color: Colorborder_color_focused: Color

Border color applied when the textarea itself is focused and focus-visible is active.

This aligns with shadcn/ui-style focus-visible:border-ring outcomes without requiring wrapper containers to own the textarea border.

focus_ring: Option<RingStyle>corner_radii: Cornerstext_color: Colorplaceholder_color: Colorselection_color: Colorcaret_color: Colorpreedit_bg_color: Colorpreedit_underline_color: Color