UiDebugInvalidationDetail

Enum UiDebugInvalidationDetail 

pub enum UiDebugInvalidationDetail {
Show 20 variants Unknown, ModelObservation, GlobalObservation, NotifyCall, HoverEvent, HoverRegionEdge, PressableHoverEdge, FocusEvent, ScrollHandleHitTestOnly, ScrollHandleLayout, ScrollHandleWindowUpdate, ScrollDeferredProbe, ScrollExtentsObservationBudgetHit, ScrollHandleScrollToItemWindowUpdate, ScrollHandleViewportResizeWindowUpdate, ScrollHandleItemsRevisionWindowUpdate, ScrollHandlePrefetchWindowUpdate, FocusVisiblePolicy, InputModalityPolicy, AnimationFrameRequest,
}

Variants



Unknown



ModelObservation



GlobalObservation



NotifyCall



HoverEvent



HoverRegionEdge

A hover edge that must re-run declarative view-cache subtrees.

HoverRegion is a mechanism-layer primitive that provides a hovered: bool signal to component code. Under view-cache reuse, paint-only invalidations do not re-run child render closures by design, so hover edges must be treated as “view dirty” to preserve the contract for hover-driven policies (e.g. hover cards).



PressableHoverEdge

A pressable hover edge that must re-run declarative view-cache subtrees.

Pressable exposes a hovered: bool signal to declarative component code. Under view-cache reuse, paint-only invalidations do not re-run child render closures by design, so hover edges must be treated as “view dirty” when component trees depend on pressable hover state to mount/unmount children (e.g. tab strip close buttons).



FocusEvent



ScrollHandleHitTestOnly



ScrollHandleLayout



ScrollHandleWindowUpdate



ScrollDeferredProbe



ScrollExtentsObservationBudgetHit



ScrollHandleScrollToItemWindowUpdate



ScrollHandleViewportResizeWindowUpdate



ScrollHandleItemsRevisionWindowUpdate



ScrollHandlePrefetchWindowUpdate



FocusVisiblePolicy



InputModalityPolicy



AnimationFrameRequest

Implementations