pub struct VisualTransformProps {
pub layout: LayoutStyle,
pub transform: Transform2D,
}Expand description
Paint-only transform wrapper for declarative element subtrees.
This applies a SceneOp::PushTransform / PopTransform around the subtree during painting,
without affecting layout, hit-testing, or pointer event coordinates.
This is intentionally similar to GPUI’s with_transformation(...) semantics for elements like
Svg: it is useful for spinners and decorative animations, and is cheap to optimize because it
does not require inverse mapping during hit-testing.
Fields
layout: LayoutStyletransform: Transform2DA transform expressed in the element’s local coordinate space.
The runtime composes this around the element’s bounds origin so that local transforms can be
expressed in px relative to the element (e.g. rotate around Point(Px(w/2), Px(h/2))).