Structs
- Continuous
Frames - Element
Context - Per-frame view construction context passed to declarative element constructors.
- Element
Runtime - Global
Element Id - Window
Element State
Traits
- Element
Context Access - Explicit access contract for APIs that only need to land UI through an
ElementContext.
Functions
- bounds_
for_ element - Returns the most recent committed bounds for a declarative element, if available.
- current_
bounds_ for_ element - Returns the most recent recorded bounds for
element, including the current frame’s in-progress layout deltas. - current_
visual_ bounds_ for_ element - Returns the most recent recorded visual bounds for
element, including the current frame’s in-progress layout deltas. - dismissible_
has_ pointer_ move_ handler - Returns
trueif the given element currently has anon_pointer_movehook installed forDismissibleLayer. - element_
identity_ is_ live_ in_ current_ frame - Returns whether
elementparticipated in the current frame’s declarative authoring pass. - element_
is_ live_ in_ current_ frame - Returns whether
elementis known to be mounted in the current frame. - global_
root - live_
node_ for_ element - Returns the current-frame node mapping for
element, if available. - node_
for_ element - Returns the most recent retained
NodeIdmapping forelement. - peek_
node_ for_ element - Returns the most recent
NodeIdmapping forelementwithout preparing element runtime for the current frame. - root_
bounds_ for_ element - take_
element_ state - visual_
bounds_ for_ element - Returns the most recent committed visual bounds (post-
render_transformAABB) for a declarative element, if available. - with_
element_ cx - with_
element_ state